@@ -498,7 +498,7 @@ mod supported {
         ctx: SessionContext,
     ) -> datafusion::error::Result<()> {
         let result = ctx
-            .sql("select name, value from information_schema.df_settings where name like 'datafusion.execution.parquet.schema_force_view_types' or name like 'datafusion.sql_parser.map_varchar_to_utf8view' order by name limit 2")
+            .sql("select name, value from information_schema.df_settings where name like 'datafusion.execution.parquet.schema_force_view_types' or name like 'datafusion.sql_parser.map_string_types_to_utf8view' order by name limit 2")
             .await?
             .collect()
             .await?;
@@ -508,7 +508,7 @@ mod supported {
             "| name                                                 | value |",
             "+------------------------------------------------------+-------+",
             "| datafusion.execution.parquet.schema_force_view_types | false |",
-            "| datafusion.sql_parser.map_varchar_to_utf8view        | false |",
+            "| datafusion.sql_parser.map_string_types_to_utf8view   | false |",
             "+------------------------------------------------------+-------+",
         ];
 
@@ -517,6 +517,41 @@ mod supported {
         Ok(())
     }
 
+    // As mentioned in https://github.com/apache/datafusion-ballista/issues/1055
+    // "Left/full outer join incorrect for CollectLeft / broadcast"
+    //
+    // In order to make correct results (decreasing performance) CollectLeft
+    // has been disabled until fixed
+
+    #[rstest]
+    #[case::standalone(standalone_context())]
+    #[case::remote(remote_context())]
+    #[tokio::test]
+    async fn should_disable_collect_left(
+        #[future(awt)]
+        #[case]
+        ctx: SessionContext,
+    ) -> datafusion::error::Result<()> {
+        let result = ctx
+            .sql("select name, value from information_schema.df_settings where name in ('datafusion.optimizer.hash_join_single_partition_threshold', 'datafusion.optimizer.hash_join_single_partition_threshold_rows') order by name limit 2")
+            .await?
+            .collect()
+            .await?;
+
+        let expected = [
+            "+----------------------------------------------------------------+-------+",
+            "| name                                                           | value |",
+            "+----------------------------------------------------------------+-------+",
+            "| datafusion.optimizer.hash_join_single_partition_threshold      | 0     |",
+            "| datafusion.optimizer.hash_join_single_partition_threshold_rows | 0     |",
+            "+----------------------------------------------------------------+-------+",
+        ];
+
+        assert_batches_eq!(expected, &result);
+
+        Ok(())
+    }
+
     #[rstest]
     #[case::standalone(standalone_context())]
     #[case::remote(remote_context())]
@@ -678,24 +713,21 @@ mod supported {
 
         assert_batches_eq!(expected, &result);
 
-        //
-        // TODO: enable when json supports lands in datafusion 47
-        //
-        // ctx.sql("select * from test")
-        //     .await?
-        //     .write_json(write_dir_path, Default::default(), Default::default())
-        //     .await?;
+        ctx.sql("select * from test")
+            .await?
+            .write_json(write_dir_path, Default::default(), Default::default())
+            .await?;
 
-        // ctx.register_json("j_written_table", write_dir_path, Default::default())
-        //     .await?;
+        ctx.register_json("j_written_table", write_dir_path, Default::default())
+            .await?;
 
-        // let result = ctx
-        //     .sql("select id, string_col from j_written_table where id > 4")
-        //     .await?
-        //     .collect()
-        //     .await?;
+        let result = ctx
+            .sql("select id, string_col from j_written_table where id > 4")
+            .await?
+            .collect()
+            .await?;
 
-        // assert_batches_eq!(expected, &result);
+        assert_batches_eq!(expected, &result);
 
         Ok(())
     }
@@ -743,4 +775,164 @@ mod supported {
 
         Ok(())
     }
+
+    #[rstest]
+    #[case::standalone(standalone_context())]
+    #[case::remote(remote_context())]
+    #[case::standalone_state(standalone_context_with_state())]
+    #[case::remote_state(remote_context_with_state())]
+    #[tokio::test]
+    async fn should_execute_group_by(
+        #[future(awt)]
+        #[case]
+        ctx: SessionContext,
+        test_data: String,
+    ) -> datafusion::error::Result<()> {
+        ctx.register_parquet(
+            "test",
+            &format!("{test_data}/alltypes_plain.parquet"),
+            Default::default(),
+        )
+        .await?;
+
+        let expected = [
+            "+------------+----------+",
+            "| string_col | count(*) |",
+            "+------------+----------+",
+            "| 30         | 1        |",
+            "| 31         | 2        |",
+            "+------------+----------+",
+        ];
+
+        let result = ctx
+            .sql("select string_col, count(*) from test where id > 4 group by string_col order by string_col")
+            .await?
+            .collect()
+            .await?;
+
+        assert_batches_eq!(expected, &result);
+
+        Ok(())
+    }
+
+    #[rstest]
+    #[case::standalone(standalone_context())]
+    #[case::remote(remote_context())]
+    #[tokio::test]
+    async fn should_force_local_read(
+        #[future(awt)]
+        #[case]
+        ctx: SessionContext,
+        test_data: String,
+    ) -> datafusion::error::Result<()> {
+        ctx.register_parquet(
+            "test",
+            &format!("{test_data}/alltypes_plain.parquet"),
+            Default::default(),
+        )
+        .await?;
+
+        ctx.sql("SET ballista.shuffle.force_remote_read = true")
+            .await?
+            .show()
+            .await?;
+
+        let result = ctx
+            .sql("select name, value from information_schema.df_settings where name like 'ballista.shuffle.force_remote_read' order by name limit 1")
+            .await?
+            .collect()
+            .await?;
+
+        let expected = [
+            "+------------------------------------+-------+",
+            "| name                               | value |",
+            "+------------------------------------+-------+",
+            "| ballista.shuffle.force_remote_read | true  |",
+            "+------------------------------------+-------+",
+        ];
+
+        assert_batches_eq!(expected, &result);
+
+        let expected = [
+            "+------------+----------+",
+            "| string_col | count(*) |",
+            "+------------+----------+",
+            "| 30         | 1        |",
+            "| 31         | 2        |",
+            "+------------+----------+",
+        ];
+
+        let result = ctx
+            .sql("select string_col, count(*) from test where id > 4 group by string_col order by string_col")
+            .await?
+            .collect()
+            .await?;
+
+        assert_batches_eq!(expected, &result);
+
+        Ok(())
+    }
+
+    #[rstest]
+    #[case::standalone(standalone_context())]
+    #[case::remote(remote_context())]
+    #[tokio::test]
+    async fn should_force_local_read_with_flight(
+        #[future(awt)]
+        #[case]
+        ctx: SessionContext,
+        test_data: String,
+    ) -> datafusion::error::Result<()> {
+        ctx.register_parquet(
+            "test",
+            &format!("{test_data}/alltypes_plain.parquet"),
+            Default::default(),
+        )
+        .await?;
+
+        ctx.sql("SET ballista.shuffle.force_remote_read = true")
+            .await?
+            .show()
+            .await?;
+
+        ctx.sql("SET ballista.shuffle.remote_read_prefer_flight = true")
+            .await?
+            .show()
+            .await?;
+
+        let result = ctx
+            .sql("select name, value from information_schema.df_settings where name like 'ballista.shuffle.remote_read_prefer_flight' order by name limit 1")
+            .await?
+            .collect()
+            .await?;
+
+        let expected = [
+            "+--------------------------------------------+-------+",
+            "| name                                       | value |",
+            "+--------------------------------------------+-------+",
+            "| ballista.shuffle.remote_read_prefer_flight | true  |",
+            "+--------------------------------------------+-------+",
+        ];
+
+        assert_batches_eq!(expected, &result);
+
+        let expected = [
+            "+------------+----------+",
+            "| string_col | count(*) |",
+            "+------------+----------+",
+            "| 30         | 1        |",
+            "| 31         | 2        |",
+            "+------------+----------+",
+        ];
+
+        let result = ctx
+            .sql("select string_col, count(*) from test where id > 4 group by string_col order by string_col")
+            .await?
+            .collect()
+            .await?;
+
+        assert_batches_eq!(expected, &result);
+
+        Ok(())
+    }
 }
