@@ -75,7 +75,7 @@ mod unsupported {
             "|               |         AggregateExec: mode=Partial, gby=[id@0 as id], aggr=[count(*)]                                                                                                                                                                                                                           |",
             "|               |           CoalesceBatchesExec: target_batch_size=8192                                                                                                                                                                                                                                            |",
             "|               |             FilterExec: id@0 > 4                                                                                                                                                                                                                                                                 |",
-            "|               |               ParquetExec: file_groups={1 group: [[Users/ballista/git/arrow-ballista/ballista/client/testdata/alltypes_plain.parquet]]}, projection=[id], predicate=id@0 > 4, pruning_predicate=CASE WHEN id_null_count@1 = id_row_count@2 THEN false ELSE id_max@0 > 4 END, required_guarantees=[] |",
+            "|               |               ParquetExec: file_groups={1 group: [[Users/ballista/git/datafusion-ballista/ballista/client/testdata/alltypes_plain.parquet]]}, projection=[id], predicate=id@0 > 4, pruning_predicate=CASE WHEN id_null_count@1 = id_row_count@2 THEN false ELSE id_max@0 > 4 END, required_guarantees=[] |",
             "|               |                                                                                                                                                                                                                                                                                                  |",
             "+---------------+--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+",        
         ];
@@ -146,69 +146,46 @@ mod unsupported {
 
         assert_batches_eq!(expected, &result);
     }
+
+    // at the moment sort merge join is not supported due to
+    // serde issues. it should be supported with DF.50
     #[rstest]
     #[case::standalone(standalone_context())]
     #[case::remote(remote_context())]
     #[tokio::test]
     #[should_panic]
-    // "Error: Internal(failed to serialize logical plan: Internal(LogicalPlan serde is not yet implemented for Dml))"
-    async fn should_support_sql_insert_into(
+    async fn should_support_sort_merge_join(
         #[future(awt)]
         #[case]
         ctx: SessionContext,
         test_data: String,
     ) {
         ctx.register_parquet(
-            "test",
+            "t0",
             &format!("{test_data}/alltypes_plain.parquet"),
             Default::default(),
         )
         .await
         .unwrap();
-        let write_dir = tempfile::tempdir().expect("temporary directory to be created");
-        let write_dir_path = write_dir
-            .path()
-            .to_str()
-            .expect("path to be converted to str");
 
-        ctx.sql("select * from test")
+        ctx.register_parquet(
+            "t1",
+            &format!("{test_data}/alltypes_plain.parquet"),
+            Default::default(),
+        )
+        .await
+        .unwrap();
+        ctx.sql("SET datafusion.optimizer.prefer_hash_join = false")
             .await
             .unwrap()
-            .write_parquet(write_dir_path, Default::default(), Default::default())
+            .show()
             .await
             .unwrap();
-
-        ctx.register_parquet("written_table", write_dir_path, Default::default())
-            .await
-            .unwrap();
-
-        let _ = ctx
-            .sql("INSERT INTO written_table select * from written_table")
+        ctx.sql("select t0.id from t0 join t1 on t0.id = t1.id")
             .await
             .unwrap()
-            .collect()
+            .show()
             .await
             .unwrap();
-
-        let result = ctx
-            .sql("select id, string_col, timestamp_col from written_table where id > 4 order by id")
-            .await.unwrap()
-            .collect()
-            .await.unwrap();
-
-        let expected = [
-            "+----+------------+---------------------+",
-            "| id | string_col | timestamp_col       |",
-            "+----+------------+---------------------+",
-            "| 5  | 31         | 2009-03-01T00:01:00 |",
-            "| 5  | 31         | 2009-03-01T00:01:00 |",
-            "| 6  | 30         | 2009-04-01T00:00:00 |",
-            "| 6  | 30         | 2009-04-01T00:00:00 |",
-            "| 7  | 31         | 2009-04-01T00:01:00 |",
-            "| 7  | 31         | 2009-04-01T00:01:00 |",
-            "+----+------------+---------------------+",
-        ];
-
-        assert_batches_eq!(expected, &result);
     }
 }
