@@ -21,8 +21,9 @@ use std::fmt::{Debug, Formatter};
 use std::sync::Arc;
 use std::time::{SystemTime, UNIX_EPOCH};
 
+use datafusion::config::ConfigOptions;
 use datafusion::physical_optimizer::aggregate_statistics::AggregateStatistics;
-use datafusion::physical_optimizer::join_selection::JoinSelection;
+//use datafusion::physical_optimizer::join_selection::JoinSelection;
 use datafusion::physical_optimizer::PhysicalOptimizerRule;
 use datafusion::physical_plan::display::DisplayableExecutionPlan;
 use datafusion::physical_plan::metrics::{MetricValue, MetricsSet};
@@ -350,7 +351,7 @@ impl UnresolvedStage {
     }
 
     /// Change to the resolved state
-    pub fn to_resolved(&self) -> Result<ResolvedStage> {
+    pub fn to_resolved(&self, options: &ConfigOptions) -> Result<ResolvedStage> {
         let input_locations = self
             .inputs
             .iter()
@@ -361,13 +362,19 @@ impl UnresolvedStage {
             &input_locations,
         )?;
 
-        let optimize_join = JoinSelection::new();
-        let config = SessionConfig::default();
-        let plan = optimize_join.optimize(plan, config.options())?;
+        // ballista specific JoinSelection, as datafusion rule can't be used here.
+        // Datafusion JoinSelection may produce plans which need change of partitions
+        // in order to be valid.
+        //
+        // we should consider changing ballista core to support adding new stages
+        // if plan changes.
+
+        let optimize_join =
+            crate::physical_optimizer::join_selection::JoinSelection::new();
+        let plan = optimize_join.optimize(plan, options)?;
 
         let optimize_aggregate = AggregateStatistics::new();
-        let plan =
-            optimize_aggregate.optimize(plan, SessionConfig::default().options())?;
+        let plan = optimize_aggregate.optimize(plan, options)?;
 
         Ok(ResolvedStage::new(
             self.stage_id,
